<?php

namespace SGalinski\SgNews\ViewHelpers\Backend;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use SGalinski\SgNews\Service\LicensingService;
use SGalinski\SgNews\ViewHelpers\AbstractViewHelper;
use TYPO3\CMS\Backend\Utility\BackendUtility;
use TYPO3\CMS\Core\Imaging\Icon;
use TYPO3\CMS\Core\Imaging\IconFactory;
use TYPO3\CMS\Core\Page\PageRenderer;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Extbase\Utility\LocalizationUtility;
use TYPO3\CMS\Recordlist\RecordList\DatabaseRecordList;

/**
 * Class ControlViewHelper
 **/
class ControlViewHelper extends AbstractViewHelper {

	/**
	 * Initialize the ViewHelper arguments
	 */
	public function initializeArguments() {
		parent::initializeArguments();
		$this->registerArgument('table', 'string', 'The table to control', TRUE);
		$this->registerArgument('row', 'mixed', 'The row of the record', TRUE);
		$this->registerArgument('sortingData', 'array', 'The sorting data', FALSE, []);
	}

	/**
	 * Renders the control buttons for the specified record
	 *
	 * @return string
	 * @throws \InvalidArgumentException
	 * @throws \UnexpectedValueException
	 */
	public function render(): string {
		$table = $this->arguments['table'];
		$row = $this->arguments['row'];
		$sortingData = $this->arguments['sortingData'];
		if (!is_array($row)) {
			$row = BackendUtility::getRecord($table, $row->getUid());
		}

		$databaseRecordList = GeneralUtility::makeInstance(DatabaseRecordList::class);
		$backendUser = $GLOBALS['BE_USER'];
		$pageInfo = BackendUtility::readPageAccess($row['pid'], $backendUser->getPagePermsClause(1));
		$databaseRecordList->calcPerms = $GLOBALS['BE_USER']->calcPerms($pageInfo);
		$pageRenderer = GeneralUtility::makeInstance(PageRenderer::class);
		$pageRenderer->loadRequireJsModule('TYPO3/CMS/Backend/AjaxDataHandler');
		$pageRenderer->addInlineLanguageLabelFile('EXT:backend/Resources/Private/Language/locallang_alt_doc.xlf');
		$languageService = GeneralUtility::makeInstance(\TYPO3\CMS\Core\Localization\LanguageService::class);
		$languageService->includeLLFile('EXT:backend/Resources/Private/Language/locallang_alt_doc.xlf');

		$databaseRecordList->currentTable = $sortingData;
		if ($table === 'pages') {
			$databaseRecordList->searchLevels = 1;
		}

		$out = $databaseRecordList->makeControl($table, $row);
		if ($table === 'pages' && LicensingService::checkKey()) {
			/** @var IconFactory $iconFactory */
			$iconFactory = GeneralUtility::makeInstance(IconFactory::class);
			$buttonLabel = LocalizationUtility::translate('backend.button.editPageContent', 'SgNews');
			$path = '';
			$onclick = 'return TYPO3.SgNewsModule.sgNewsGoToPageModule(' . $row['uid'] . $path . ');';
			$icon = $iconFactory->getIcon('actions-document-open-white', Icon::SIZE_SMALL)->render();
			$wrap = ' <div class="btn-group" role="group">%s</div>';
			$link = '<a href="#" onclick="' . $onclick . '" class="btn btn-primary" title="' . $buttonLabel . '">%s</a>';
			$link = sprintf($link, $icon . ' ' . $buttonLabel);
			$out .= sprintf($wrap, $link);
		}

		return $out;
	}
}
